@@ -11,9 +11,31 @@ use switchboard_protos::protos::fulfillment_manager::FulfillmentManagerState;
 use switchboard_protos::protos::fulfillment_manager::mod_FulfillmentManagerState;
 use switchboard_protos::protos::switchboard_account_types::SwitchboardAccountType;
 use zerocopy::{AsBytes, FromBytes};
-use anchor_lang::{AnchorSerialize, AnchorDeserialize};
 use std::io::Error;
 use std::io::Write;
+use rust_decimal::prelude::Decimal;
+use rust_decimal::prelude::FromPrimitive;
+
+#[derive(Default,AsBytes,FromBytes,Clone,Debug)]
+#[repr(C)]
+pub struct SwitchboardDecimal {
+    pub mantissa: i128,
+    pub scale: u64
+}
+
+impl SwitchboardDecimal {
+    pub fn from_f64(input: f64) -> Option<Self> {
+        let dec = Decimal::from_f64(input);
+        if dec.is_none() {
+            return None;
+        }
+        let dec = dec.unwrap();
+        Some(Self {
+            mantissa: dec.mantissa(),
+            scale: dec.scale().into(),
+        })
+    }
+}
 
 pub type PubkeyBuffer = [u8; 32];
 
@@ -28,6 +50,8 @@ pub struct FastRoundResult {
     pub round_open_timestamp: i64,
     pub min_response: f64,
     pub max_response: f64,
+    // Rust decimal representation of the current result.
+    pub decimal: SwitchboardDecimal,
 }
 
 #[derive(Default,AsBytes,FromBytes,Clone,Debug)]
@@ -207,6 +231,7 @@ pub mod mod_test_utils {
             current_round_result: None,
             last_round_result: None,
             parse_optimized_result_address: None,
+            bundle_auth_addresses: Vec::new(),
         }
     }
 
